<?php

declare(strict_types=1);

namespace Dedi\SyliusCustomerPoolPlugin\DataFixtures\Factory;

use Dedi\SyliusCustomerPoolPlugin\Model\Customer\CustomerPoolAwareInterface;
use Sylius\Bundle\CoreBundle\Fixture\Factory\ChannelExampleFactory;
use Sylius\Component\Channel\Factory\ChannelFactoryInterface;
use Sylius\Component\Core\Model\ChannelInterface;
use Sylius\Component\Resource\Factory\FactoryInterface;
use Sylius\Component\Resource\Repository\RepositoryInterface;
use Sylius\Component\Taxonomy\Repository\TaxonRepositoryInterface;
use Webmozart\Assert\Assert;

class ChannelWithCustomerPoolFactory extends ChannelExampleFactory
{
    /** @var RepositoryInterface  */
    private $customerPoolRepository;

    public function __construct(
        ChannelFactoryInterface $channelFactory,
        RepositoryInterface $localeRepository,
        RepositoryInterface $currencyRepository,
        RepositoryInterface $zoneRepository,
        ?TaxonRepositoryInterface $taxonRepository = null,
        ?FactoryInterface $shopBillingDataFactory = null,
        RepositoryInterface $customerPoolRepository
    ) {
        parent::__construct(
            $channelFactory,
            $localeRepository,
            $currencyRepository,
            $zoneRepository,
            $taxonRepository,
            $shopBillingDataFactory
        );

        $this->customerPoolRepository = $customerPoolRepository;
    }

    public function create(array $options = []): ChannelInterface
    {
        /** @var CustomerPoolAwareInterface|ChannelInterface $channel */
        $channel = parent::create($options);

        Assert::isInstanceOf($channel, CustomerPoolAwareInterface::class);

        $customerPool = $this->customerPoolRepository->findOneBy(['code' => 'Default']);
        $channel->setCustomerPool($customerPool);

        return $channel;
    }
}
